pro trace_get1www_image, file_dset
;+
;   Name: trace_get1www_image
;
;   Purpose: satisfy single image requests in 'near real time'  
;
;   Input Parameters:
;      file_dset - xxxxxYYYYMMDD.HHMM_NNNN   (YYYYMMDD.HHMM=>hourly file)
;                                                      NNNN=>image# )
;   Side Effects:
;      Flat FITS file written to: $path_http/img_client  
;
;   History:
;	Written by S.L.Freeland Circa 5-May-1998 
;	13-May-98 (FZ)  - Changed from color to black & white
;       18-May-98  S.L.Freeland
;-  

box_message,file_dset
; -------- use the FILE_DSET to link image/html documents ---------
file=(strsplit(file_dset,'_',tail=imgss))(0)
outdir=concat_dir(get_logenv('path_http'),'image_client')
fname=strtrim(file_dset(0),2)
outfits=fname+'.fits'
outthumb =fname+'_thumb.gif'
outhtml=concat_dir(outdir,fname+'.html')
; ------------------------------------------------------------------

if file(0) eq '' or imgss(0) eq '' then begin
  box_message,'Illegal query string'
endif else begin
;  --------- derive online file name ----------------
   weekly='week'+anytim2weekinfo(file2time(file(0)),/first)
   indir=concat_dir('$TRACE_I1_DIR',weekly)
   infile=(concat_dir(indir,file(0)))(0)
   if not file_exist(infile) then begin
      box_message,'File not found: ' + infile(0)
   endif else begin
;     -------------- set up read_trace call ----------------
      dset=fix(imgss)
      mess='File '  + file + ' , image# ' + strtrim(dset,2)
      box_message,'Reading '+ mess

;     ---------- read_trace/write_trace ---------
      read_trace,infile, fix(dset), index, data 
      if data_chk(data,/nimage) eq 0 then begin

      endif  
      write_trace, index, data , outdir=outdir, $
	  outfile=concat_dir(outdir,outfits), /flat
;     --------------------------------------------

;     ------------ make a thumbnail -------------
      wave=gt_tagval(index,/wave_len,miss='??')
      swave=wave
      if is_number(wave) then begin
	  iwave=fix(wave)
	  swave=swave+' &#197'
      endif else iwave=3
;      iwave=0
;      ssw_ct2rgb,iwave,r,g,b,gamma=.7,hi=!p.color
      trace_colors,iwave,r,g,b, /full_range
       box_message,'running trace_colors, wave=:' + strtrim(iwave,2)
       nx=([256,512])(gt_tagval(index,/naxis1,missing=256) eq 1024)
       print,'using nx='+strtrim(nx,2)
       thumb=mkthumb(trace_auto_scale(index, data),r,g,b,nx=nx,$
		    outfile=concat_dir(outdir,outthumb))
;     --------------------------------------------
      fitssize=file_size(concat_dir(outdir,outfits),/string,/auto)
;      summ=get_infox(index,'naxis1,naxis2',fmt_tim='ecs')+ swave + $
       summ= ' Raw 2D FITS file ' + fitssize + '&#32 <em>'+ swave +'</em>'
      tr_head_info,index,outarr,/quiet, $
  tags=str2arr('date_obs,wave_len,naxis1,naxis1,cdelt1,xcen,ycen,obs_prog,frm_nam,trg_nam,sou_area,img_min,img_max,img_avg,img_dev')
      cols=str2cols(outarr,'=')

;     --------------- generate an WWW documnent -------------
      html_doc,outhtml,/header
      file_append,outhtml,['<h2>TRACE Image WWW summary</h2>',$
		   '<em><b>',mess,'</b></em><p>']
      file_append,outhtml,$
   '<a href="/cgi-bin/disp_fits.pl?'+concat_dir(outdir,outfits) +'"><img src="/TRACE/image_client/' + $
      outthumb+'"><p><font color=red size=+2>' + summ + '</font></a>
      file_append,outhtml,strtab2html(cols([1,2,0],*),/left)
      html_doc,outhtml,/trailer      
;     ---------------------------------------------------
      box_message,http_names(outhtml)
    endelse   
endelse    

return
end
  
