function trace_wwwidl_watchdog, serverip, host, loud=loud, $
				restart=restart, force_restart=force_restart
;+
;   Name: watchdog check an idlwww server - restart on error
;-
loud=keyword_set(loud)
force_restart=keyword_set(force_restart)

if n_elements(rpcid) eq 0 then rpcid='0X2010CAFE'
if n_elements(cgidir) eq 0 then cgidir='/var/www/cgi-bin/'
if n_elements(serverip) eq 0 then serverip=get_host()
if n_elements(host) eq 0 then host=get_host(/short)

rpcclient=ssw_bin('idlRpcClient',found=found)

if not found then begin
  box_message,'Cannot find IDL RPC client in SSW tree, returning...'
  return, 0
endif  

info=wwwidl_watchdog(file, value)       ; get   "expected" values
count_file=file+'.counter'

if not file_exist(count_file) then $
    file_append,count_file,long(str2arr('0,0')),/new

; ------ the UPDATED command is via RPC -> WWWIDL SERVER ----
rpccmd='status=wwwidl_watchdog(/update,"'+file+'","'+ value+'")'
cmd=[rpcclient,rpcid,serverip,rpccmd]
box_message,['Spawing command...',cmd(0:2),'status=wwwidl_watchdog(/update)']
spawn,cmd,/noshell,output
if output(0) ne '' then box_message,['Output from spawn',output]
; --------------------------------------------------

; ------- check locally to see if the server did the correct thing
retval=wwwidl_watchdog(file,value,/check)
counter=long(rd_tfile(count_file,nocomment=';'))

status=(['FAILED','PASSED'])(retval)
counter(retval)=counter(retval)+1
mess=['Watchdog Test ' + status + ' by Sever ' + host, value]  

mess=[mess,'Failures: '   + strtrim(counter(0),2) + '  ' + $
            'Successes: ' + strtrim(counter(1),2)]

if loud then box_message,mess
                          
file_append,count_file,['; ' + mess,strtrim(counter,2)],/new

if (keyword_set(restart) and (1-retval)) or force_restart then begin
   box_message,'Failure  - Initiating restart...'
   cmd=[rpcclient,rpcid,serverip,'retall']
   mess0=['Spawing command...',cmd]
   box_message,mess0
   spawn,cmd,/noshell,output
   if not trace_wwwidl_watchdog(/loud) then begin
      mess1='RETALL recovery did not work, restarting server...'
      box_message,mess1
      servstart=concat_dir('$SSW_SITE_SETUP','start_idlserver_5')
      cmd=['csh','-f',servstart]
      spawn,cmd,/noshell                 
   endif else mess1='RETALL recovery worked'
   mail,[mess0,mess1],user='freeland@penumbra.nascom.nasa.gov', $
	 subj='TRACE IDLWWW Server WATCHDOG', /no_defsub
endif

return, retval
end
